'use es6';

import {expect} from 'chai';

import GoogleDirectionsTranslationService from '../src/services/GoogleDirectionsTranslationService';
import Coordinate from '../src/data/Coordinate';
import Leg from '../src/data/Leg';
import Step from '../src/data/Step';
import TransitAgency from '../src/data/TransitAgency';
import TransitDetails from '../src/data/TransitDetails';
import TransitLine from '../src/data/TransitLine';
import TransitStop from '../src/data/TransitStop';
import {TRANSIT_VEHICLE} from '../src/data/TransitVehicle';
import {TRAVEL_MODE} from '../src/data/TravelMode';

import exampleDirectionsFile from './files/example-directions.json';

describe('Google directions translation service', function() {
  const expectedFirstStep = new Step({
    distanceMeters: 341,
    durationSeconds: 266,
    endLocation: new Coordinate({
      latitude: 40.67838,
      longitude: -73.94821999999999,
    }),
    htmlInstructions: 'Walk to Nostrand Avenue',
    startLocation: new Coordinate({
      latitude: 40.678183,
      longitude: -73.94416129999999,
    }),
    transitDetails: new TransitDetails(),
    travelMode: TRAVEL_MODE.WALKING,
  });

  const expectedSecondStep = new Step({
    distanceMeters: 12270,
    durationSeconds: 900,
    endLocation: new Coordinate({
      latitude: 40.6996,
      longitude: -73.80852999999999,
    }),
    htmlInstructions: 'Train towards Far Rockaway',
    startLocation: new Coordinate({
      latitude: 40.67838,
      longitude: -73.94821999999999,
    }),
    transitDetails: new TransitDetails({
      arrivalTransitStop: new TransitStop({
        location: new Coordinate({
          latitude: 40.6996,
          longitude: -73.80852999999999,
        }),
        name: 'Jamaica',
      }),
      arrivalTimestamp: 1468978440,
      departureTransitStop: new TransitStop({
        location: new Coordinate({
          latitude: 40.67838,
          longitude: -73.94821999999999,
        }),
        name: 'Nostrand Avenue',
      }),
      departureTimestamp: 1468977540,
      headsign: 'Far Rockaway',
      line: new TransitLine({
        agencies: [
          new TransitAgency({
            name: 'Long Island Rail Road',
            phoneNumber: '1 (718) 558-7400',
            uri: 'http://web.mta.info/lirr',
          })
        ],
        color: '#6e3219',
        name: 'Far Rockaway',
        shortName: '',
        vehicle: TRANSIT_VEHICLE.HEAVY_RAIL,
      }),
      stopCount: 2,
    }),
    travelMode: TRAVEL_MODE.TRANSIT,
  });

  const expectedThirdStep = new Step({
    distanceMeters: 112,
    durationSeconds: 112,
    endLocation: new Coordinate({
      latitude: 40.700489,
      longitude: -73.807884,
    }),
    htmlInstructions: 'Walk to Archer Av/Sutphin Bl',
    startLocation: new Coordinate({
      latitude: 40.6996,
      longitude: -73.80852999999999,
    }),
    transitDetails: new TransitDetails(),
    travelMode: TRAVEL_MODE.WALKING,  
  });

  const expectedFourthStep = new Step({
    distanceMeters: 4605,
    durationSeconds: 1020,
    endLocation: new Coordinate({
      latitude: 40.728783,
      longitude: -73.79284699999999,
    }),
    htmlInstructions: 'Bus towards Bayside 27 Av F Lewis Bl',
    startLocation: new Coordinate({
      latitude: 40.700489,
      longitude: -73.807884,
    }),
    transitDetails: new TransitDetails({
      arrivalTransitStop: new TransitStop({
        location: new Coordinate({
          latitude: 40.728783,
          longitude: -73.79284699999999,
        }),
        name: 'Utopia Py/75 Av',
      }),
      arrivalTimestamp: 1468980120,
      departureTransitStop: new TransitStop({
        location: new Coordinate({
          latitude: 40.700489,
          longitude: -73.807884,
        }),
        name: 'Archer Av/Sutphin Bl',
      }),
      departureTimestamp: 1468979100,
      headsign: 'Bayside 27 Av F Lewis Bl',
      line: new TransitLine({
        agencies: [
          new TransitAgency({
            name: 'MTA New York City Transit',
            phoneNumber: '1 (718) 330-1234',
            uri: 'http://www.mta.info/',
          })
        ],
        color: '#f9a825',
        name: 'Bayside - Jamaica',
        shortName: 'Q31',
        vehicle: TRANSIT_VEHICLE.BUS,
      }),
      stopCount: 18,
    }),
    travelMode: TRAVEL_MODE.TRANSIT,
  });

const expectedFifthStep = new Step({
    distanceMeters: 230,
    durationSeconds: 189,
    endLocation: new Coordinate({
      latitude: 40.7282259,
      longitude: -73.7948332,
    }),
    htmlInstructions: 'Walk to Queens County, NY, USA',
    startLocation: new Coordinate({
      latitude: 40.728783,
      longitude: -73.79284699999999,
    }),
    transitDetails: new TransitDetails(),
    travelMode: TRAVEL_MODE.WALKING,  
  });

  const expectedFirstLeg = new Leg({
    arrivalTimestamp: 1468980310,
    departureTimestamp: 1468977274,
    distanceMeters: 17558,
    durationSeconds: 3036,
    endAddress: 'Queens County, NY, USA',
    endLocation: new Coordinate({
      latitude: 40.7282259,
      longitude: -73.7948332,
    }),
    startAddress: 'Brooklyn, NY, USA',
    startLocation: new Coordinate({
      latitude: 40.678183,
      longitude: -73.94416129999999,
    }),
    steps: [expectedFirstStep, expectedSecondStep, expectedThirdStep, expectedFourthStep, expectedFifthStep],
  });

  it('tests translation', function() {
    expect(GoogleDirectionsTranslationService.translateDirections(exampleDirectionsFile)).to.eql([[expectedFirstLeg]]);
  });
});